Method: Git::Base#fetch
- Defined in:
- lib/git/base.rb
#fetch(remote = 'origin', opts = {})
fetches changes from a remote branch - this does not modify the working directory, it just gets the changes from the remote if there are any
485 486 487 488 489 490 491 |
# File 'lib/git/base.rb', line 485 def fetch(remote = 'origin', opts = {}) if remote.is_a?(Hash) opts = remote remote = nil end lib.fetch(remote, opts) end |