Class: Git::BranchDeleteFailure

Inherits:
Data
  • Object
show all
Defined in:
lib/git/branch_delete_failure.rb

Overview

Represents a branch that failed to be deleted

This is an immutable data object returned as part of BranchDeleteResult when one or more branches could not be deleted.

Examples:

failure = Git::BranchDeleteFailure.new(
  name: 'nonexistent',
  error_message: "branch 'nonexistent' not found."
)
failure.name          #=> 'nonexistent'
failure.error_message #=> "branch 'nonexistent' not found."

See Also:

Instance Attribute Summary collapse

Instance Attribute Details

#error_messageString (readonly)

The error message from git explaining why the branch could not be deleted

Returns:

  • (String)


33
# File 'lib/git/branch_delete_failure.rb', line 33

BranchDeleteFailure = Data.define(:name, :error_message)

#nameString (readonly)

The name of the branch that failed to be deleted

Returns:

  • (String)


33
# File 'lib/git/branch_delete_failure.rb', line 33

BranchDeleteFailure = Data.define(:name, :error_message)