Class: Git::Commands::Add Private
Overview
This class is part of a private API. You should avoid using this class if possible, as it may be removed or be changed in the future.
Note:
arguments block audited against https://git-scm.com/docs/git-add/2.53.0
Implements the git add command
This command updates the index using the current content found in the working tree, to prepare the content staged for the next commit.
Instance Method Summary collapse
-
#call(*pathspec, **options) ⇒ Git::CommandLine::Result
private
Execute the
git addcommand.
Methods inherited from Base
allow_exit_status, arguments, #initialize, requires_git_version, skip_version_validation
Constructor Details
This class inherits a constructor from Git::Commands::Base
Instance Method Details
#call(*pathspec, **options) ⇒ Git::CommandLine::Result
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
134 135 136 |
# File 'lib/git/commands/add.rb', line 134 def call(*, **) super end |