Module: Git::Commands::Am Private

Defined in:
lib/git/commands/am.rb,
lib/git/commands/am/quit.rb,
lib/git/commands/am/skip.rb,
lib/git/commands/am/abort.rb,
lib/git/commands/am/apply.rb,
lib/git/commands/am/retry.rb,
lib/git/commands/am/continue.rb,
lib/git/commands/am/show_current_patch.rb

Overview

This module is part of a private API. You should avoid using this module if possible, as it may be removed or be changed in the future.

Commands for applying patches from a mailbox via git am

This module contains command classes for patch application and session management:

  • Apply — apply a series of patches from a mailbox
  • Abort — abort the current patch application (--abort)
  • Continue — resume after resolving conflicts (--continue)
  • Quit — drop the current patch session (--quit)
  • Retry — retry the current patch
  • ShowCurrentPatch — show the patch being applied (--show-current-patch)
  • Skip — skip the current patch (--skip)

Defined Under Namespace

Classes: Abort, Apply, Continue, Quit, Retry, ShowCurrentPatch, Skip