Class: Git::Commands::Am::Abort Private

Inherits:
Base
  • Object
show all
Defined in:
lib/git/commands/am/abort.rb

Overview

This class is part of a private API. You should avoid using this class if possible, as it may be removed or be changed in the future.

Note:

arguments block audited against https://git-scm.com/docs/git-am/2.53.0

Implements git am --abort to abort an in-progress am session

Aborts the in-progress patch application and restores the branch to the state it was in before the git am session started.

Examples:

Abort an am session

abort_cmd = Git::Commands::Am::Abort.new(execution_context)
abort_cmd.call

See Also:

Instance Method Summary collapse

Methods inherited from Base

allow_exit_status, arguments, #initialize, requires_git_version, skip_version_validation

Constructor Details

This class inherits a constructor from Git::Commands::Base

Instance Method Details

#callGit::CommandLineResult

Abort the in-progress am session and restore the branch

Returns:

Raises:



# File 'lib/git/commands/am/abort.rb', line 31