Class: Git::Commands::Am::Continue Private

Inherits:
Base
  • Object
show all
Defined in:
lib/git/commands/am/continue.rb

Overview

This class is part of a private API. You should avoid using this class if possible, as it may be removed or be changed in the future.

Note:

arguments block audited against https://git-scm.com/docs/git-am/2.53.0

Implements git am --continue to resume after resolving conflicts

After the user has resolved a conflict in the working tree and updated the index, this command continues applying the remaining patches.

Examples:

Resume an am session after resolving conflicts

continue_cmd = Git::Commands::Am::Continue.new(execution_context)
continue_cmd.call

See Also:

Instance Method Summary collapse

Methods inherited from Base

allow_exit_status, arguments, #initialize, requires_git_version, skip_version_validation

Constructor Details

This class inherits a constructor from Git::Commands::Base

Instance Method Details

#callGit::CommandLineResult

Resume applying patches after conflicts have been resolved

Returns:

Raises:



# File 'lib/git/commands/am/continue.rb', line 31