Class: Git::Commands::Am::Retry Private

Inherits:
Base
  • Object
show all
Defined in:
lib/git/commands/am/retry.rb

Overview

This class is part of a private API. You should avoid using this class if possible, as it may be removed or be changed in the future.

Note:

arguments block audited against https://git-scm.com/docs/git-am/2.53.0

Implements git am --retry to retry the most-recently-failed patch

Tries to apply the last conflicting patch again. Generally only useful when retrying with extra options (e.g. --3way), or in scripts where stdin is not a tty and the implicit retry heuristic does not trigger.

Examples:

Retry the current patch

retry_cmd = Git::Commands::Am::Retry.new(execution_context)
retry_cmd.call

See Also:

Instance Method Summary collapse

Methods inherited from Base

allow_exit_status, arguments, #initialize, requires_git_version, skip_version_validation

Constructor Details

This class inherits a constructor from Git::Commands::Base

Instance Method Details

#callGit::CommandLineResult

Retry applying the most-recently-failed patch

Returns:

Raises:



# File 'lib/git/commands/am/retry.rb', line 35