Class: Git::Commands::Am::Skip Private

Inherits:
Base
  • Object
show all
Defined in:
lib/git/commands/am/skip.rb

Overview

This class is part of a private API. You should avoid using this class if possible, as it may be removed or be changed in the future.

Note:

arguments block audited against https://git-scm.com/docs/git-am/2.53.0

Implements git am --skip to skip the current patch

Skips the current patch and continues applying remaining patches.

Examples:

Skip a conflicting patch

skip_cmd = Git::Commands::Am::Skip.new(execution_context)
skip_cmd.call

See Also:

Instance Method Summary collapse

Methods inherited from Base

allow_exit_status, arguments, #initialize, requires_git_version, skip_version_validation

Constructor Details

This class inherits a constructor from Git::Commands::Base

Instance Method Details

#callGit::CommandLineResult

Skip the current patch and continue with remaining patches

Returns:

Raises:



# File 'lib/git/commands/am/skip.rb', line 30