Class: Git::Commands::Archive::ListFormats Private

Inherits:
Base
  • Object
show all
Defined in:
lib/git/commands/archive/list_formats.rb

Overview

This class is part of a private API. You should avoid using this class if possible, as it may be removed or be changed in the future.

Note:

arguments block audited against https://git-scm.com/docs/git-archive/2.53.0

Format lister for git archive --list

Lists all available archive formats supported by the current git installation. This is a standalone mode of git archive that does not require a tree-ish operand.

Examples:

List available archive formats

cmd = Git::Commands::Archive::ListFormats.new(execution_context)
result = cmd.call
result.stdout  # => "tar\ntgz\ntar.gz\nzip\n"

See Also:

Instance Method Summary collapse

Methods inherited from Base

allow_exit_status, arguments, #initialize, requires_git_version, skip_version_validation

Constructor Details

This class inherits a constructor from Git::Commands::Base

Instance Method Details

#callGit::CommandLineResult

Execute git archive --list to show available formats.

Returns:

Raises:



# File 'lib/git/commands/archive/list_formats.rb', line 34