Class: Git::Commands::Branch::Copy Private
- Inherits:
-
Git::Commands::Base
- Object
- Git::Commands::Base
- Git::Commands::Branch::Copy
- Defined in:
- lib/git/commands/branch/copy.rb
Overview
This class is part of a private API. You should avoid using this class if possible, as it may be removed or be changed in the future.
Note:
arguments block audited against https://git-scm.com/docs/git-branch/2.53.0
Implements the git branch --copy command for copying branches
This command copies a branch, together with its config and reflog. If the old branch name is omitted, copies the current branch.
Instance Method Summary collapse
-
#call(*, **)
Execute the git branch --copy command to copy a branch.
Methods inherited from Git::Commands::Base
allow_exit_status, arguments, #initialize, requires_git_version, skip_version_validation
Constructor Details
This class inherits a constructor from Git::Commands::Base
Instance Method Details
#call(new_branch, **options) ⇒ Git::CommandLineResult #call(old_branch, new_branch, **options) ⇒ Git::CommandLineResult
Execute the git branch --copy command to copy a branch
|
|
# File 'lib/git/commands/branch/copy.rb', line 50
|