Class: Git::Commands::Clean Private
Overview
This class is part of a private API. You should avoid using this class if possible, as it may be removed or be changed in the future.
arguments block audited against https://git-scm.com/docs/git-clean/2.53.0
Remove untracked files from the working tree
Cleans the working tree by recursively removing files that are not under
version control. Only files unknown to Git are removed by default; with
:x also removes ignored files; with :X removes only ignored files.
Instance Method Summary collapse
-
#call(**options) ⇒ Git::CommandLine::Result
private
@api public.
Methods inherited from Base
allow_exit_status, arguments, #initialize, requires_git_version, skip_version_validation
Constructor Details
This class inherits a constructor from Git::Commands::Base
Instance Method Details
#call(**options) ⇒ Git::CommandLine::Result
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
@api public
97 98 99 |
# File 'lib/git/commands/clean.rb', line 97 def call(*, **) super end |