Class: Git::Commands::Gc Private
Overview
This class is part of a private API. You should avoid using this class if possible, as it may be removed or be changed in the future.
arguments block audited against
https://git-scm.com/docs/git-gc/2.53.0
Implements the git gc command
Runs a number of housekeeping tasks within the current repository, such as compressing file revisions (to reduce disk space and increase performance), removing unreachable objects, packing refs, pruning reflog, rerere metadata or stale working trees.
Instance Method Summary collapse
-
#call(**options) ⇒ Git::CommandLine::Result
private
Execute the
git gccommand.
Methods inherited from Base
allow_exit_status, arguments, #initialize, requires_git_version, skip_version_validation
Constructor Details
This class inherits a constructor from Git::Commands::Base
Instance Method Details
#call(**options) ⇒ Git::CommandLine::Result
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
129 130 131 |
# File 'lib/git/commands/gc.rb', line 129 def call(*, **) super end |