Class: Git::Commands::LsFiles Private
Overview
This class is part of a private API. You should avoid using this class if possible, as it may be removed or be changed in the future.
Note:
arguments block audited against https://git-scm.com/docs/git-ls-files/2.53.0
Implements the git ls-files command.
This command shows information about files in the index and the working tree. It is used to list tracked, untracked, ignored, and staged files.
Instance Method Summary collapse
-
#call(*file, **options) ⇒ Git::CommandLine::Result
private
Execute the
git ls-filescommand.
Methods inherited from Base
allow_exit_status, arguments, #initialize, requires_git_version, skip_version_validation
Constructor Details
This class inherits a constructor from Git::Commands::Base
Instance Method Details
#call(*file, **options) ⇒ Git::CommandLine::Result
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
190 191 192 |
# File 'lib/git/commands/ls_files.rb', line 190 def call(*, **) super end |