Class: Git::Commands::Maintenance::Stop Private

Inherits:
Base
  • Object
show all
Defined in:
lib/git/commands/maintenance/stop.rb

Overview

This class is part of a private API. You should avoid using this class if possible, as it may be removed or be changed in the future.

Note:

arguments block audited against https://git-scm.com/docs/git-maintenance/2.54.0

Halt the background maintenance schedule

Examples:

Stop background maintenance

Git::Commands::Maintenance::Stop.new(execution_context).call

See Also:

Instance Method Summary collapse

Methods inherited from Base

allow_exit_status, arguments, #initialize, requires_git_version, skip_version_validation

Constructor Details

This class inherits a constructor from Git::Commands::Base

Instance Method Details

#call(**options) ⇒ Git::CommandLineResult

Halt the background maintenance schedule

The current repository is not removed from the list of maintained repositories, in case the background maintenance is restarted later.

Parameters:

  • options (Hash)

    command options

Options Hash (**options):

  • :env (Hash) — default: nil

    environment variables to set for the git process; merged with the default environment; not passed to the git CLI

Returns:

Raises:

  • (ArgumentError)

    if unsupported options are provided

  • (Git::FailedError)

    if git exits with a non-zero exit status

  • (Git::VersionError)

    if git version is below 2.30.0



# File 'lib/git/commands/maintenance/stop.rb', line 31