Module: Git::Commands::Merge Private

Defined in:
lib/git/commands/merge.rb,
lib/git/commands/merge/quit.rb,
lib/git/commands/merge/abort.rb,
lib/git/commands/merge/start.rb,
lib/git/commands/merge/continue.rb

Overview

This module is part of a private API. You should avoid using this module if possible, as it may be removed or be changed in the future.

Commands for joining development histories via git merge

This module contains command classes for the initial merge (Start) and session management (Continue, Abort, Quit):

  • Start — merge one or more branches into the current branch
  • Continue — resume after resolving merge conflicts (--continue)
  • Abort — abort the in-progress merge (--abort)
  • Quit — forget the in-progress merge but leave the working tree as-is (--quit)

Defined Under Namespace

Classes: Abort, Continue, Quit, Start