Class: Git::Commands::Remote::Remove Private

Inherits:
Base
  • Object
show all
Defined in:
lib/git/commands/remote/remove.rb

Overview

This class is part of a private API. You should avoid using this class if possible, as it may be removed or be changed in the future.

Note:

arguments block audited against https://git-scm.com/docs/git-remote/2.53.0

git remote remove command

Removes a remote and its associated tracking refs and configuration.

Examples:

Remove a remote

remove = Git::Commands::Remote::Remove.new(execution_context)
remove.call('origin')

Remove a remote with a name that looks like a flag

remove = Git::Commands::Remote::Remove.new(execution_context)
remove.call('-weirdremote')

See Also:

Instance Method Summary collapse

Methods inherited from Base

allow_exit_status, arguments, #initialize, requires_git_version, skip_version_validation

Constructor Details

This class inherits a constructor from Git::Commands::Base

Instance Method Details

#call(name) ⇒ Git::CommandLineResult

Execute the git remote remove command

Parameters:

  • name (String)

    the remote name to remove

Returns:

Raises:



# File 'lib/git/commands/remote/remove.rb', line 38