Class: Git::Commands::Revert::Abort Private

Inherits:
Base
  • Object
show all
Defined in:
lib/git/commands/revert/abort.rb

Overview

This class is part of a private API. You should avoid using this class if possible, as it may be removed or be changed in the future.

Note:

arguments block audited against https://git-scm.com/docs/git-revert/2.53.0

Implements git revert --abort to cancel an in-progress revert sequence

Cancels the in-progress revert and restores the branch to the state it was in before the git revert sequence started.

Examples:

Abort an in-progress revert

abort_cmd = Git::Commands::Revert::Abort.new(execution_context)
abort_cmd.call

See Also:

Instance Method Summary collapse

Methods inherited from Base

allow_exit_status, arguments, #initialize, requires_git_version, skip_version_validation

Constructor Details

This class inherits a constructor from Git::Commands::Base

Instance Method Details

#callGit::CommandLineResult

Cancel the in-progress revert and restore the branch to its pre-revert state

Returns:

Raises:



# File 'lib/git/commands/revert/abort.rb', line 31