Class: Git::Commands::Revert::Continue Private

Inherits:
Base
  • Object
show all
Defined in:
lib/git/commands/revert/continue.rb

Overview

This class is part of a private API. You should avoid using this class if possible, as it may be removed or be changed in the future.

Note:

arguments block audited against https://git-scm.com/docs/git-revert/2.53.0

Implements git revert --continue to resume after resolving conflicts

After the user has resolved a conflict and staged the changes, the revert session can be continued with this command.

Examples:

Resume a revert session after resolving conflicts

continue_cmd = Git::Commands::Revert::Continue.new(execution_context)
continue_cmd.call

See Also:

Instance Method Summary collapse

Methods inherited from Base

allow_exit_status, arguments, #initialize, requires_git_version, skip_version_validation

Constructor Details

This class inherits a constructor from Git::Commands::Base

Instance Method Details

#call(**options) ⇒ Git::CommandLineResult

Resume the in-progress revert after conflicts have been resolved

Parameters:

  • options (Hash)

    command options

Options Hash (**options):

  • :edit (Boolean, nil) — default: nil

    open the editor for the commit message (--edit)

    Alias: :e

  • :no_edit (Boolean, nil) — default: nil

    suppress the editor for the commit message (--no-edit)

Returns:

Raises:

  • (ArgumentError)

    if unsupported options are provided

  • (Git::FailedError)

    if git exits with a non-zero exit status



# File 'lib/git/commands/revert/continue.rb', line 32