Class: Git::Commands::Revert::Quit Private

Inherits:
Base
  • Object
show all
Defined in:
lib/git/commands/revert/quit.rb

Overview

This class is part of a private API. You should avoid using this class if possible, as it may be removed or be changed in the future.

Note:

arguments block audited against https://git-scm.com/docs/git-revert/2.53.0

Implements git revert --quit to forget an in-progress revert sequence

Clears the sequencer state without restoring the branch, leaving the working tree and index in their current state. If no revert is in progress, this is a no-op and still succeeds.

Examples:

Forget an in-progress revert session

quit_cmd = Git::Commands::Revert::Quit.new(execution_context)
quit_cmd.call

See Also:

Instance Method Summary collapse

Methods inherited from Base

allow_exit_status, arguments, #initialize, requires_git_version, skip_version_validation

Constructor Details

This class inherits a constructor from Git::Commands::Base

Instance Method Details

#callGit::CommandLineResult

Clear any in-progress revert sequencer state, leaving the working tree as-is. If no revert is in progress, this is a no-op and still succeeds.

Returns:

Raises:



# File 'lib/git/commands/revert/quit.rb', line 32