Class: Git::Commands::Stash::Apply Private
- Defined in:
- lib/git/commands/stash/apply.rb
Overview
This class is part of a private API. You should avoid using this class if possible, as it may be removed or be changed in the future.
Note:
arguments block audited against https://git-scm.com/docs/git-stash/2.53.0
Apply stashed changes to the working directory
Applies the changes recorded in a stash to the working tree. Unlike Pop, this does not remove the stash from the stash list.
Instance Method Summary collapse
-
#call(*, **) ⇒ Git::CommandLineResult
Apply stashed changes.
Methods inherited from Base
allow_exit_status, arguments, #initialize, requires_git_version, skip_version_validation
Constructor Details
This class inherits a constructor from Git::Commands::Base
Instance Method Details
#call(**options) ⇒ Git::CommandLineResult #call(stash, **options) ⇒ Git::CommandLineResult
Apply stashed changes
|
|
# File 'lib/git/commands/stash/apply.rb', line 39
|