Class: Git::Commands::SymbolicRef::Update Private
- Defined in:
- lib/git/commands/symbolic_ref/update.rb
Overview
This class is part of a private API. You should avoid using this class if possible, as it may be removed or be changed in the future.
arguments block audited against https://git-scm.com/docs/git-symbolic-ref/2.53.0
Creates or updates a symbolic ref via git symbolic-ref
Given two arguments, creates or updates a symbolic ref <name> to
point at the given branch <ref>.
Instance Method Summary collapse
-
#call(name, ref, **options) ⇒ Git::CommandLine::Result
private
Executes the git symbolic-ref command to create or update a symbolic ref.
Methods inherited from Base
allow_exit_status, arguments, #initialize, requires_git_version, skip_version_validation
Constructor Details
This class inherits a constructor from Git::Commands::Base
Instance Method Details
#call(name, ref, **options) ⇒ Git::CommandLine::Result
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Executes the git symbolic-ref command to create or update a symbolic ref
73 74 75 |
# File 'lib/git/commands/symbolic_ref/update.rb', line 73 def call(*, **) super end |