Class: Git::Commands::Worktree::Unlock Private

Inherits:
ManagementBase show all
Defined in:
lib/git/commands/worktree/unlock.rb

Overview

This class is part of a private API. You should avoid using this class if possible, as it may be removed or be changed in the future.

Note:

arguments block audited against https://git-scm.com/docs/git-worktree/2.54.0

Unlocks a worktree, allowing it to be pruned, moved, or deleted

Examples:

Unlock a worktree

Git::Commands::Worktree::Unlock.new(execution_context).call('/tmp/feature')

See Also:

Instance Method Summary collapse

Methods inherited from Base

allow_exit_status, arguments, #initialize, requires_git_version, skip_version_validation

Constructor Details

This class inherits a constructor from Git::Commands::Base

Instance Method Details

#call(worktree) ⇒ Git::CommandLineResult

Unlock a worktree, allowing it to be pruned, moved, or deleted

Parameters:

  • worktree (String)

    path or unique suffix identifying the worktree to unlock

Returns:

Raises:



# File 'lib/git/commands/worktree/unlock.rb', line 30