Class: Git::ExecutionContext::Global Private
- Inherits:
-
ExecutionContext
- Object
- ExecutionContext
- Git::ExecutionContext::Global
- Defined in:
- lib/git/execution_context/global.rb
Overview
This class is part of a private API. You should avoid using this class if possible, as it may be removed or be changed in the future.
Execution context for global git commands (no repository required)
Used for commands that do not require an existing repository — such as
git init, git clone, and git version. Unlike
Repository, this class leaves GIT_DIR,
GIT_WORK_TREE, and GIT_INDEX_FILE as nil (which unsets them), so
that the parent environment cannot leak an unintended repository context.
GIT_SSH is still supported to allow SSH-based remote operations
(e.g. git clone git@github.com:...).