Class: Git::FailedError

Inherits:
CommandLineError
  • Object
show all
Defined in:
lib/git/errors.rb

Overview

This error is raised when a git command returns a non-zero exitstatus

The git command executed, status, stdout, and stderr are available from this object.