Class: Git::TagDeleteFailure

Inherits:
Data
  • Object
show all
Defined in:
lib/git/tag_delete_failure.rb

Overview

Represents a tag that failed to be deleted

This is an immutable data object returned as part of TagDeleteResult when one or more tags could not be deleted.

Examples:

failure = Git::TagDeleteFailure.new(
  name: 'nonexistent',
  error_message: "tag 'nonexistent' not found."
)
failure.name          #=> 'nonexistent'
failure.error_message #=> "tag 'nonexistent' not found."

See Also:

Instance Attribute Summary collapse

Instance Attribute Details

#error_messageString (readonly)

The error message from git explaining why the tag could not be deleted

Returns:

  • (String)


33
# File 'lib/git/tag_delete_failure.rb', line 33

TagDeleteFailure = Data.define(:name, :error_message)

#nameString (readonly)

The name of the tag that failed to be deleted

Returns:

  • (String)


33
# File 'lib/git/tag_delete_failure.rb', line 33

TagDeleteFailure = Data.define(:name, :error_message)