Method: Git::Lib#cat_file_tag
- Defined in:
- lib/git/lib.rb
#cat_file_tag(object) ⇒ Hash Also known as: tag_data
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Return a hash of annotated tag data
Does not work with lightweight tags. List all annotated tags in your repository with the following command:
git for-each-ref --format='%(refname:strip=2)' refs/tags | \
while read tag; do git cat-file tag $tag >/dev/null 2>&1 && echo $tag; done
The returned commit data has the following keys:
- object [String] the sha of the tag object
- type [String]
- tag [String] tag name
- tagger [String] the name and email of the user who created the tag and the timestamp of when the tag was created
- message [String] the tag message
569 570 571 572 573 574 |
# File 'lib/git/lib.rb', line 569 def cat_file_tag(object) ('object', object) tdata = command_lines('cat-file', 'tag', object) process_tag_data(tdata, object) end |