Class: Git::BranchDeleteFailure
- Inherits:
-
Data
- Object
- Data
- Git::BranchDeleteFailure
- Defined in:
- lib/git/branch_delete_failure.rb
Overview
Represents a branch that failed to be deleted
This is an immutable data object returned as part of BranchDeleteResult when one or more branches could not be deleted.
Instance Attribute Summary collapse
-
#error_message ⇒ String
readonly
The error message from git explaining why the branch could not be deleted.
-
#name ⇒ String
readonly
The name of the branch that failed to be deleted.
Instance Attribute Details
#error_message ⇒ String (readonly)
The error message from git explaining why the branch could not be deleted
33 |
# File 'lib/git/branch_delete_failure.rb', line 33 BranchDeleteFailure = Data.define(:name, :error_message) |
#name ⇒ String (readonly)
The name of the branch that failed to be deleted
33 |
# File 'lib/git/branch_delete_failure.rb', line 33 BranchDeleteFailure = Data.define(:name, :error_message) |