Class: Git::Commands::Add Private
Overview
This class is part of a private API. You should avoid using this class if possible, as it may be removed or be changed in the future.
Note:
arguments block audited against https://git-scm.com/docs/git-add/2.53.0
Implements the git add command
This command updates the index using the current content found in the working tree, to prepare the content staged for the next commit.
Instance Method Summary collapse
-
#call(*pathspec, **options) ⇒ Git::CommandLineResult
Execute the
git addcommand.
Methods inherited from Base
allow_exit_status, arguments, #initialize, requires_git_version, skip_version_validation
Constructor Details
This class inherits a constructor from Git::Commands::Base