Class: Git::Commands::Am::Continue Private
- Defined in:
- lib/git/commands/am/continue.rb
Overview
This class is part of a private API. You should avoid using this class if possible, as it may be removed or be changed in the future.
Note:
arguments block audited against https://git-scm.com/docs/git-am/2.53.0
Implements git am --continue to resume after resolving conflicts
After the user has resolved a conflict in the working tree and updated the index, this command continues applying the remaining patches.
Instance Method Summary collapse
-
#call ⇒ Git::CommandLineResult
Resume applying patches after conflicts have been resolved.
Methods inherited from Base
allow_exit_status, arguments, #initialize, requires_git_version, skip_version_validation
Constructor Details
This class inherits a constructor from Git::Commands::Base