Class: Git::Commands::Am::Skip Private
Overview
This class is part of a private API. You should avoid using this class if possible, as it may be removed or be changed in the future.
Note:
arguments block audited against https://git-scm.com/docs/git-am/2.53.0
Implements git am --skip to skip the current patch
Skips the current patch and continues applying remaining patches.
Instance Method Summary collapse
-
#call ⇒ Git::CommandLineResult
Skip the current patch and continue with remaining patches.
Methods inherited from Base
allow_exit_status, arguments, #initialize, requires_git_version, skip_version_validation
Constructor Details
This class inherits a constructor from Git::Commands::Base