Class: Git::Commands::Archive Private
- Defined in:
- lib/git/commands/archive.rb,
lib/git/commands/archive/list_formats.rb
Overview
This class is part of a private API. You should avoid using this class if possible, as it may be removed or be changed in the future.
arguments block audited against https://git-scm.com/docs/git-archive/2.53.0
Archive creator for files from a named tree via git archive
Produces an archive of the specified format containing the tree structure
for the named tree, and writes it to stdout (or to a file when out: or
output: is given). If prefix: is specified it is prepended to the
filenames in the archive.
Defined Under Namespace
Classes: ListFormats
Instance Method Summary collapse
-
#call(tree_ish = nil, *path, **options) ⇒ Git::CommandLineResult
Execute the
git archivecommand. -
#chomp_captured_stdout? ⇒ Boolean
private
Archive output is binary, so preserve captured stdout byte-for-byte even when it ends with a newline.
-
#normalize_captured_stdout? ⇒ Boolean
private
Archive output is intrinsically binary (tar, zip, etc.) — opt out of Ruby string normalization and trailing-newline chomping so that
result.stdoutbytes are returned unchanged.
Methods inherited from Base
allow_exit_status, arguments, #initialize, requires_git_version, skip_version_validation
Constructor Details
This class inherits a constructor from Git::Commands::Base
Instance Method Details
#call(tree_ish = nil, *path, **options) ⇒ Git::CommandLineResult
|
|
# File 'lib/git/commands/archive.rb', line 58
|
#chomp_captured_stdout? ⇒ Boolean
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Archive output is binary, so preserve captured stdout byte-for-byte even when it ends with a newline.
137 |
# File 'lib/git/commands/archive.rb', line 137 def chomp_captured_stdout? = false |
#normalize_captured_stdout? ⇒ Boolean
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Archive output is intrinsically binary (tar, zip, etc.) — opt out of
Ruby string normalization and trailing-newline chomping so that
result.stdout bytes are returned unchanged. Only affects the
capturing path; streaming via out: is never normalized or chomped
regardless of these settings.
130 |
# File 'lib/git/commands/archive.rb', line 130 def normalize_captured_stdout? = false |