Class: Git::Commands::Archive::ListFormats Private
- Defined in:
- lib/git/commands/archive/list_formats.rb
Overview
This class is part of a private API. You should avoid using this class if possible, as it may be removed or be changed in the future.
Note:
arguments block audited against https://git-scm.com/docs/git-archive/2.53.0
Format lister for git archive --list
Lists all available archive formats supported by the current git
installation. This is a standalone mode of git archive that does not
require a tree-ish operand.
Instance Method Summary collapse
-
#call ⇒ Git::CommandLineResult
Execute
git archive --listto show available formats.
Methods inherited from Base
allow_exit_status, arguments, #initialize, requires_git_version, skip_version_validation
Constructor Details
This class inherits a constructor from Git::Commands::Base