Class: Git::Commands::Branch::SetUpstream Private
- Inherits:
-
Git::Commands::Base
- Object
- Git::Commands::Base
- Git::Commands::Branch::SetUpstream
- Defined in:
- lib/git/commands/branch/set_upstream.rb
Overview
This class is part of a private API. You should avoid using this class if possible, as it may be removed or be changed in the future.
Note:
arguments block audited against https://git-scm.com/docs/git-branch/2.53.0
Implements the git branch --set-upstream-to command for configuring upstream tracking
This command sets up tracking information so the specified upstream branch is considered the upstream for the given branch (or current branch if not specified).
Instance Method Summary collapse
-
#call(*, **)
Execute the git branch --set-upstream-to command.
Methods inherited from Git::Commands::Base
allow_exit_status, arguments, #initialize, requires_git_version, skip_version_validation
Constructor Details
This class inherits a constructor from Git::Commands::Base
Instance Method Details
#call(**options) ⇒ Git::CommandLineResult #call(branch_name, **options) ⇒ Git::CommandLineResult
Execute the git branch --set-upstream-to command
|
|
# File 'lib/git/commands/branch/set_upstream.rb', line 42
|