Module: Git::Commands::CatFile Private
- Defined in:
- lib/git/commands/cat_file.rb,
lib/git/commands/cat_file/raw.rb,
lib/git/commands/cat_file/batch.rb,
lib/git/commands/cat_file/filtered.rb
Overview
This module is part of a private API. You should avoid using this module if possible, as it may be removed or be changed in the future.
Commands for reading git object store content via git cat-file
This module contains command classes split by invocation protocol:
- Raw — single object as a CLI argument; raw content, type, size, or
existence check (
-e,-t,-s,-p,<type>) - Filtered — single object as a CLI argument; content after
.gitattributesfilter processing (--textconv,--filters) - Batch — objects fed via stdin; all batch streaming modes
(
--batch,--batch-check,--batch-command)