Module: Git::Commands::Checkout Private
- Defined in:
- lib/git/commands/checkout.rb,
lib/git/commands/checkout/files.rb,
lib/git/commands/checkout/branch.rb
Overview
This module is part of a private API. You should avoid using this module if possible, as it may be removed or be changed in the future.
Commands for switching branches and restoring files via git checkout
This module contains command classes split by checkout mode: