Class: Git::Commands::Checkout::Branch Private
- Defined in:
- lib/git/commands/checkout/branch.rb
Overview
This class is part of a private API. You should avoid using this class if possible, as it may be removed or be changed in the future.
arguments block audited against https://git-scm.com/docs/git-checkout/2.53.0
Implements the git checkout command for switching branches
This command switches branches by updating the index and working tree
to match the specified branch, and updating HEAD to point to that branch.
It can also create new branches with the -b or -B options.
Instance Method Summary collapse
-
#call(branch = nil, **options) ⇒ Git::CommandLine::Result
private
@api public.
Methods inherited from Base
allow_exit_status, arguments, #initialize, requires_git_version, skip_version_validation
Constructor Details
This class inherits a constructor from Git::Commands::Base
Instance Method Details
#call(branch = nil, **options) ⇒ Git::CommandLine::Result
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
@api public
147 148 149 |
# File 'lib/git/commands/checkout/branch.rb', line 147 def call(*, **) super end |