Class: Git::Commands::CheckoutIndex Private
- Defined in:
- lib/git/commands/checkout_index.rb
Overview
This class is part of a private API. You should avoid using this class if possible, as it may be removed or be changed in the future.
Note:
arguments block audited against https://git-scm.com/docs/git-checkout-index/2.53.0
Implements the git checkout-index command
This command copies all files listed in the index to the working directory (not overwriting existing files). It is typically used to populate a new working directory from the current index, optionally scoped to a specific path or prefix.
Instance Method Summary collapse
-
#call(*file, **options) ⇒ Git::CommandLineResult
Execute the
git checkout-indexcommand.
Methods inherited from Base
allow_exit_status, arguments, #initialize, requires_git_version, skip_version_validation
Constructor Details
This class inherits a constructor from Git::Commands::Base
Instance Method Details
#call(*file, **options) ⇒ Git::CommandLineResult
|
|
# File 'lib/git/commands/checkout_index.rb', line 45
|