Class: Git::Commands::Describe Private
- Defined in:
- lib/git/commands/describe.rb
Overview
This class is part of a private API. You should avoid using this class if possible, as it may be removed or be changed in the future.
Note:
arguments block audited against
https://git-scm.com/docs/git-describe/2.53.0
Implements the git describe command
Gives a human-readable name to a commit based on the most recent reachable tag. When the tag points directly at the commit, only the tag name is shown. Otherwise, the tag name is suffixed with the number of additional commits and the abbreviated commit SHA.
Instance Method Summary collapse
-
#call(*commit_ish, **options) ⇒ Git::CommandLineResult
Execute the
git describecommand.
Methods inherited from Base
allow_exit_status, arguments, #initialize, requires_git_version, skip_version_validation
Constructor Details
This class inherits a constructor from Git::Commands::Base
Instance Method Details
#call(*commit_ish, **options) ⇒ Git::CommandLineResult
|
|
# File 'lib/git/commands/describe.rb', line 67
|