Class: Git::Commands::Fsck Private
Overview
This class is part of a private API. You should avoid using this class if possible, as it may be removed or be changed in the future.
Note:
arguments block audited against https://git-scm.com/docs/git-fsck/2.53.0
Implements the git fsck command
Verifies the connectivity and validity of objects in the database. It checks the integrity of the repository, reporting any dangling, missing, or unreachable objects.
Instance Method Summary collapse
-
#call(*object, **options) ⇒ Git::CommandLineResult
Execute the
git fsckcommand.
Methods inherited from Base
allow_exit_status, arguments, #initialize, requires_git_version, skip_version_validation
Constructor Details
This class inherits a constructor from Git::Commands::Base