Class: Git::Commands::Gc Private
Overview
This class is part of a private API. You should avoid using this class if possible, as it may be removed or be changed in the future.
Note:
arguments block audited against
https://git-scm.com/docs/git-gc/2.53.0
Implements the git gc command
Runs a number of housekeeping tasks within the current repository, such as compressing file revisions (to reduce disk space and increase performance), removing unreachable objects, packing refs, pruning reflog, rerere metadata or stale working trees.
Instance Method Summary collapse
-
#call(**options) ⇒ Git::CommandLineResult
Execute the
git gccommand.
Methods inherited from Base
allow_exit_status, arguments, #initialize, requires_git_version, skip_version_validation
Constructor Details
This class inherits a constructor from Git::Commands::Base