Class: Git::Commands::LsRemote Private
- Defined in:
- lib/git/commands/ls_remote.rb
Overview
This class is part of a private API. You should avoid using this class if possible, as it may be removed or be changed in the future.
Note:
arguments block audited against https://git-scm.com/docs/git-ls-remote/2.53.0
Implements the git ls-remote command
Lists references available in a remote repository along with the associated commit IDs. Can be used to detect changes in a remote repository without cloning or fetching.
Instance Method Summary collapse
-
#call(repository = nil, *patterns, **options) ⇒ Git::CommandLineResult
Execute the
git ls-remotecommand.
Methods inherited from Base
allow_exit_status, arguments, #initialize, requires_git_version, skip_version_validation
Constructor Details
This class inherits a constructor from Git::Commands::Base
Instance Method Details
#call(repository = nil, *patterns, **options) ⇒ Git::CommandLineResult
|
|
# File 'lib/git/commands/ls_remote.rb', line 74
|