Class: Git::Commands::LsTree Private
Overview
This class is part of a private API. You should avoid using this class if possible, as it may be removed or be changed in the future.
Note:
arguments block audited against https://git-scm.com/docs/git-ls-tree/2.53.0
Implements the git ls-tree command
Lists the contents of a tree object, showing the mode, type, object name, and file name of each item. Supports recursive listing, output format control, and path filtering.
Instance Method Summary collapse
-
#call(tree_ish, *path, **options) ⇒ Git::CommandLineResult
Execute the git ls-tree command.
Methods inherited from Base
allow_exit_status, arguments, #initialize, requires_git_version, skip_version_validation
Constructor Details
This class inherits a constructor from Git::Commands::Base
Instance Method Details
#call(tree_ish, *path, **options) ⇒ Git::CommandLineResult
|
|
# File 'lib/git/commands/ls_tree.rb', line 60
|