Class: Git::Commands::Merge::Continue Private
- Defined in:
- lib/git/commands/merge/continue.rb
Overview
This class is part of a private API. You should avoid using this class if possible, as it may be removed or be changed in the future.
Note:
arguments block audited against https://git-scm.com/docs/git-merge/2.53.0
Implements git merge --continue to complete a merge after conflict resolution
After the user has resolved conflicts and staged the changes, the merge can be concluded with this command.
Instance Method Summary collapse
-
#call ⇒ Git::CommandLineResult
Resume the in-progress merge after conflicts have been resolved.
Methods inherited from Base
allow_exit_status, arguments, #initialize, requires_git_version, skip_version_validation
Constructor Details
This class inherits a constructor from Git::Commands::Base