Class: Git::Commands::Merge::Quit Private
- Defined in:
- lib/git/commands/merge/quit.rb
Overview
This class is part of a private API. You should avoid using this class if possible, as it may be removed or be changed in the future.
Note:
arguments block audited against https://git-scm.com/docs/git-merge/2.53.0
Implements git merge --quit to quit an in-progress merge
Forgets about the current merge in progress. Leaves the index and working tree as-is. If an autostash entry is present, saves it to the stash list.
Instance Method Summary collapse
-
#call ⇒ Git::CommandLineResult
Forget about the current merge in progress, leaving the index and working tree as-is.
Methods inherited from Base
allow_exit_status, arguments, #initialize, requires_git_version, skip_version_validation
Constructor Details
This class inherits a constructor from Git::Commands::Base