Class: Git::Commands::MergeBase Private
- Defined in:
- lib/git/commands/merge_base.rb
Overview
This class is part of a private API. You should avoid using this class if possible, as it may be removed or be changed in the future.
Note:
arguments block audited against
https://git-scm.com/docs/git-merge-base/2.53.0
Implements the git merge-base command to find common ancestors
Finds as good common ancestors as possible for use in a three-way merge. Given two or more commits, it outputs a common ancestor reachable from all of them through the parent relationship.
Instance Method Summary collapse
-
#call(*commit, **options) ⇒ Git::CommandLineResult
Execute the
git merge-basecommand.
Methods inherited from Base
allow_exit_status, arguments, #initialize, requires_git_version, skip_version_validation
Constructor Details
This class inherits a constructor from Git::Commands::Base