Class: Git::Commands::Remote::Add Private
- Defined in:
- lib/git/commands/remote/add.rb
Overview
This class is part of a private API. You should avoid using this class if possible, as it may be removed or be changed in the future.
Note:
arguments block audited against https://git-scm.com/docs/git-remote/2.53.0
git remote add command
Adds a new remote to the repository, associating a name with a URL and configuring how tracking branches and tags are handled.
Instance Method Summary collapse
-
#call(name, url, **options) ⇒ Git::CommandLineResult
Execute the
git remote addcommand.
Methods inherited from Base
allow_exit_status, arguments, #initialize, requires_git_version, skip_version_validation
Constructor Details
This class inherits a constructor from Git::Commands::Base
Instance Method Details
#call(name, url, **options) ⇒ Git::CommandLineResult
|
|
# File 'lib/git/commands/remote/add.rb', line 49
|