Class: Git::Commands::Reset Private
Overview
This class is part of a private API. You should avoid using this class if possible, as it may be removed or be changed in the future.
Note:
arguments block audited against
https://git-scm.com/docs/git-reset/2.53.0
Implements the git reset command
Resets the current HEAD to a specified state, or updates the staged version of specified files to match the state from a given commit or tree.
Instance Method Summary collapse
-
#call(commit = nil, **options) ⇒ Git::CommandLineResult
Execute the git reset command.
Methods inherited from Base
allow_exit_status, arguments, #initialize, requires_git_version, skip_version_validation
Constructor Details
This class inherits a constructor from Git::Commands::Base
Instance Method Details
#call(commit = nil, **options) ⇒ Git::CommandLineResult
Execute the git reset command.
|
|
# File 'lib/git/commands/reset.rb', line 75
|