Class: Git::Commands::Revert::Continue Private
- Defined in:
- lib/git/commands/revert/continue.rb
Overview
This class is part of a private API. You should avoid using this class if possible, as it may be removed or be changed in the future.
Note:
arguments block audited against https://git-scm.com/docs/git-revert/2.53.0
Implements git revert --continue to resume after resolving conflicts
After the user has resolved a conflict and staged the changes, the revert session can be continued with this command.
Instance Method Summary collapse
-
#call(**options) ⇒ Git::CommandLineResult
Resume the in-progress revert after conflicts have been resolved.
Methods inherited from Base
allow_exit_status, arguments, #initialize, requires_git_version, skip_version_validation
Constructor Details
This class inherits a constructor from Git::Commands::Base