Class: Git::Commands::Revert::Skip Private
- Defined in:
- lib/git/commands/revert/skip.rb
Overview
This class is part of a private API. You should avoid using this class if possible, as it may be removed or be changed in the future.
Note:
arguments block audited against https://git-scm.com/docs/git-revert/2.53.0
Implements git revert --skip to skip the current commit in a sequence
Skips the current commit and continues applying the remaining commits in the revert sequence.
Instance Method Summary collapse
-
#call ⇒ Git::CommandLineResult
Skip the current commit and continue with the remaining sequence.
Methods inherited from Base
allow_exit_status, arguments, #initialize, requires_git_version, skip_version_validation
Constructor Details
This class inherits a constructor from Git::Commands::Base