Class: Git::Commands::Revert::Start Private
- Defined in:
- lib/git/commands/revert/start.rb
Overview
This class is part of a private API. You should avoid using this class if possible, as it may be removed or be changed in the future.
Note:
arguments block audited against https://git-scm.com/docs/git-revert/2.53.0
Implements git revert to create commits that undo prior changes
Given one or more existing commits, reverts the changes introduced by those commits and records new commits that reverse them. This requires the working tree to be clean.
Instance Method Summary collapse
-
#call(*commit, **options) ⇒ Git::CommandLineResult
Execute the git revert command.
Methods inherited from Base
allow_exit_status, arguments, #initialize, requires_git_version, skip_version_validation
Constructor Details
This class inherits a constructor from Git::Commands::Base
Instance Method Details
#call(*commit, **options) ⇒ Git::CommandLineResult
|
|
# File 'lib/git/commands/revert/start.rb', line 73
|