Module: Git::Commands::Stash Private
- Defined in:
- lib/git/commands/stash.rb,
lib/git/commands/stash/pop.rb,
lib/git/commands/stash/drop.rb,
lib/git/commands/stash/list.rb,
lib/git/commands/stash/push.rb,
lib/git/commands/stash/show.rb,
lib/git/commands/stash/apply.rb,
lib/git/commands/stash/clear.rb,
lib/git/commands/stash/store.rb,
lib/git/commands/stash/branch.rb,
lib/git/commands/stash/create.rb
Overview
This module is part of a private API. You should avoid using this module if possible, as it may be removed or be changed in the future.
Commands for stashing working directory changes via git stash
This module contains command classes split by stash operation:
- Push — save changes to a new stash entry
- Pop — apply the top stash and remove it from the stash list
- Apply — apply a stash without removing it
- Drop — remove a single stash entry
- Clear — remove all stash entries
- List — list stash entries
- Show — show changes recorded in a stash entry
- Branch — create a new branch from a stash entry
- Create — create a stash object without storing it
- Store — store a stash object created with
create
Defined Under Namespace
Classes: Apply, Branch, Clear, Create, Drop, List, Pop, Push, Show, Store