Class: Git::Commands::Stash::Push Private
- Defined in:
- lib/git/commands/stash/push.rb
Overview
This class is part of a private API. You should avoid using this class if possible, as it may be removed or be changed in the future.
Note:
arguments block audited against https://git-scm.com/docs/git-stash/2.53.0
Stash changes in the working directory
Saves local modifications to a new stash entry and rolls them back to HEAD (in the working tree and index). The command takes various options to customize what gets stashed.
Instance Method Summary collapse
-
#call(*pathspec, **options) ⇒ Git::CommandLineResult
Stash changes in the working directory.
Methods inherited from Base
allow_exit_status, arguments, #initialize, requires_git_version, skip_version_validation
Constructor Details
This class inherits a constructor from Git::Commands::Base
Instance Method Details
#call(*pathspec, **options) ⇒ Git::CommandLineResult
|
|
# File 'lib/git/commands/stash/push.rb', line 51
|