Class: Git::Commands::Stash::Show Private
- Defined in:
- lib/git/commands/stash/show.rb
Overview
This class is part of a private API. You should avoid using this class if possible, as it may be removed or be changed in the future.
Note:
arguments block audited against https://git-scm.com/docs/git-stash/2.53.0
Show the changes recorded in a stash entry as a diff
Shows the changes recorded in the stash entry as a diff between the stashed contents and the commit back when the stash entry was first created.
Instance Method Summary collapse
-
#call(*, **) ⇒ Git::CommandLineResult
Show stash diff.
Methods inherited from Base
allow_exit_status, arguments, #initialize, requires_git_version, skip_version_validation
Constructor Details
This class inherits a constructor from Git::Commands::Base
Instance Method Details
#call(**options) ⇒ Git::CommandLineResult #call(stash, **options) ⇒ Git::CommandLineResult
Show stash diff
|
|
# File 'lib/git/commands/stash/show.rb', line 53
|