Class: Git::Commands::Status Private
Overview
This class is part of a private API. You should avoid using this class if possible, as it may be removed or be changed in the future.
Note:
arguments block audited against
https://git-scm.com/docs/git-status/2.53.0
Implements the git status command
Shows the working tree status — the differences between the index and the current HEAD commit, and between the working directory and the index.
Instance Method Summary collapse
-
#call(*pathspecs, **options) ⇒ Git::CommandLineResult
Execute the git status command.
Methods inherited from Base
allow_exit_status, arguments, #initialize, requires_git_version, skip_version_validation
Constructor Details
This class inherits a constructor from Git::Commands::Base