Module: Git::Commands::SymbolicRef Private
- Defined in:
- lib/git/commands/symbolic_ref.rb,
lib/git/commands/symbolic_ref/read.rb,
lib/git/commands/symbolic_ref/delete.rb,
lib/git/commands/symbolic_ref/update.rb
Overview
This module is part of a private API. You should avoid using this module if possible, as it may be removed or be changed in the future.
Commands for reading, updating, and deleting symbolic refs via
git symbolic-ref
This module contains command classes split by invocation mode: