Class: Git::Commands::SymbolicRef::Read Private
- Defined in:
- lib/git/commands/symbolic_ref/read.rb
Overview
This class is part of a private API. You should avoid using this class if possible, as it may be removed or be changed in the future.
arguments block audited against https://git-scm.com/docs/git-symbolic-ref/2.53.0
Reads the target of a symbolic ref via git symbolic-ref
Given one argument, reads which branch head the given symbolic ref
refers to and outputs its path, relative to the .git/ directory.
Exits with status 0 if the contents were printed correctly, or
status 1 if the requested name is not a symbolic ref (e.g. a
detached HEAD). When quiet: true, exit status 1 is silent
(no error message on stderr).
Instance Method Summary collapse
-
#call(name, **options) ⇒ Git::CommandLineResult
Execute the
git symbolic-refcommand to read a symbolic ref.
Methods inherited from Base
allow_exit_status, arguments, #initialize, requires_git_version, skip_version_validation
Constructor Details
This class inherits a constructor from Git::Commands::Base
Instance Method Details
#call(name, **options) ⇒ Git::CommandLineResult
|
|
# File 'lib/git/commands/symbolic_ref/read.rb', line 59
|