Class: Git::Commands::Tag::Create Private
- Defined in:
- lib/git/commands/tag/create.rb
Overview
This class is part of a private API. You should avoid using this class if possible, as it may be removed or be changed in the future.
Note:
arguments block audited against https://git-scm.com/docs/git-tag/2.53.0
Implements the git tag command for creating new tags
This command creates a new tag reference pointing at the current HEAD or a specified commit/object.
Instance Method Summary collapse
-
#call(tagname, commit = nil, **options) ⇒ Git::CommandLineResult
Execute the git tag command to create a new tag.
Methods inherited from Base
allow_exit_status, arguments, #initialize, requires_git_version, skip_version_validation
Constructor Details
This class inherits a constructor from Git::Commands::Base
Instance Method Details
#call(tagname, commit = nil, **options) ⇒ Git::CommandLineResult
Execute the git tag command to create a new tag
|
|
# File 'lib/git/commands/tag/create.rb', line 57
|