Class: Git::Commands::Tag::Verify Private
- Defined in:
- lib/git/commands/tag/verify.rb
Overview
This class is part of a private API. You should avoid using this class if possible, as it may be removed or be changed in the future.
Note:
arguments block audited against https://git-scm.com/docs/git-tag/2.53.0
Implements the git tag --verify command for verifying tag signatures
This command verifies the cryptographic signature of the given tag(s). It requires that the tags were signed with GPG or another supported signing backend.
Instance Method Summary collapse
-
#call(*tagname, **options) ⇒ Git::CommandLineResult
Execute the git tag --verify command to verify tag signatures.
Methods inherited from Base
allow_exit_status, arguments, #initialize, requires_git_version, skip_version_validation
Constructor Details
This class inherits a constructor from Git::Commands::Base
Instance Method Details
#call(*tagname, **options) ⇒ Git::CommandLineResult
Execute the git tag --verify command to verify tag signatures
|
|
# File 'lib/git/commands/tag/verify.rb', line 45
|