Class: Git::Commands::Worktree::Lock Private
- Inherits:
-
ManagementBase
- Object
- Base
- ManagementBase
- Git::Commands::Worktree::Lock
- Defined in:
- lib/git/commands/worktree/lock.rb
Overview
This class is part of a private API. You should avoid using this class if possible, as it may be removed or be changed in the future.
Note:
arguments block audited against
https://git-scm.com/docs/git-worktree/2.54.0
Locks a worktree to prevent it from being pruned
Instance Method Summary collapse
-
#call(worktree, **options) ⇒ Git::CommandLineResult
Lock a worktree to prevent it from being pruned.
Methods inherited from Base
allow_exit_status, arguments, #initialize, requires_git_version, skip_version_validation
Constructor Details
This class inherits a constructor from Git::Commands::Base
Instance Method Details
#call(worktree, **options) ⇒ Git::CommandLineResult
|
|
# File 'lib/git/commands/worktree/lock.rb', line 34
|