Class: Git::Commands::Worktree::Move Private
- Inherits:
-
ManagementBase
- Object
- Base
- ManagementBase
- Git::Commands::Worktree::Move
- Defined in:
- lib/git/commands/worktree/move.rb
Overview
This class is part of a private API. You should avoid using this class if possible, as it may be removed or be changed in the future.
Note:
arguments block audited against
https://git-scm.com/docs/git-worktree/2.54.0
Moves a linked worktree to a new filesystem location
Instance Method Summary collapse
-
#call(worktree, new_path, **options) ⇒ Git::CommandLineResult
Move a linked worktree to a new filesystem location.
Methods inherited from Base
allow_exit_status, arguments, #initialize, requires_git_version, skip_version_validation
Constructor Details
This class inherits a constructor from Git::Commands::Base
Instance Method Details
#call(worktree, new_path, **options) ⇒ Git::CommandLineResult
|
|
# File 'lib/git/commands/worktree/move.rb', line 35
|