Class: Git::Commands::Worktree::Unlock Private
- Inherits:
-
ManagementBase
- Object
- Base
- ManagementBase
- Git::Commands::Worktree::Unlock
- Defined in:
- lib/git/commands/worktree/unlock.rb
Overview
This class is part of a private API. You should avoid using this class if possible, as it may be removed or be changed in the future.
Note:
arguments block audited against
https://git-scm.com/docs/git-worktree/2.54.0
Unlocks a worktree, allowing it to be pruned, moved, or deleted
Instance Method Summary collapse
-
#call(worktree) ⇒ Git::CommandLineResult
Unlock a worktree, allowing it to be pruned, moved, or deleted.
Methods inherited from Base
allow_exit_status, arguments, #initialize, requires_git_version, skip_version_validation
Constructor Details
This class inherits a constructor from Git::Commands::Base