Class: Git::Commands::WriteTree Private
- Defined in:
- lib/git/commands/write_tree.rb
Overview
This class is part of a private API. You should avoid using this class if possible, as it may be removed or be changed in the future.
Note:
arguments block audited against https://git-scm.com/docs/git-write-tree/2.53.0
Implements the git write-tree command
Creates a tree object using the current index and prints the SHA-1 name of the new tree object to standard output. The index must be in a fully merged state.
Instance Method Summary collapse
-
#call(**options) ⇒ Git::CommandLineResult
Execute the
git write-treecommand.
Methods inherited from Base
allow_exit_status, arguments, #initialize, requires_git_version, skip_version_validation
Constructor Details
This class inherits a constructor from Git::Commands::Base