Class: Git::DirstatEntry Private
- Inherits:
-
Data
- Object
- Data
- Git::DirstatEntry
- Defined in:
- lib/git/dirstat_info.rb
Overview
This class is part of a private API. You should avoid using this class if possible, as it may be removed or be changed in the future.
Immutable value object representing a single directory's contribution to a diff
Work in progress; this class is internal for now and may be made public in a future release.
Instance Attribute Summary collapse
-
#directory ⇒ String
readonly
The directory path (always ends with '/').
-
#percentage ⇒ Float
readonly
The percentage of changes in this directory (0.0-100.0).
Instance Attribute Details
#directory ⇒ String (readonly)
Returns the directory path (always ends with '/').
21 |
# File 'lib/git/dirstat_info.rb', line 21 DirstatEntry = Data.define(:directory, :percentage) |
#percentage ⇒ Float (readonly)
Returns the percentage of changes in this directory (0.0-100.0).
21 |
# File 'lib/git/dirstat_info.rb', line 21 DirstatEntry = Data.define(:directory, :percentage) |