Class: Git::Lib
- Inherits:
-
Object
- Object
- Git::Lib
- Defined in:
- lib/git/lib.rb
Constant Summary collapse
- @@semaphore =
Mutex.new
Instance Method Summary collapse
-
#add(paths = '.', options = {}) ⇒ Object
updates the repository index using the working directory content.
- #apply(patch_file) ⇒ Object
- #apply_mail(patch_file) ⇒ Object
-
#archive(sha, file = nil, opts = {}) ⇒ Object
creates an archive file.
- #branch_contains(commit, branch_name = "") ⇒ Object
- #branch_current ⇒ Object
- #branch_delete(branch) ⇒ Object
- #branch_new(branch) ⇒ Object
- #branches_all ⇒ Object
- #change_head_branch(branch_name) ⇒ Object
- #checkout(branch, opts = {}) ⇒ Object
- #checkout_file(version, file) ⇒ Object
- #checkout_index(opts = {}) ⇒ Object
- #clean(opts = {}) ⇒ Object
-
#clone(repository, name, opts = {}) ⇒ Object
tries to clone the given repo.
-
#commit(message, opts = {}) ⇒ Object
Takes the commit message with the options and executes the commit command.
-
#commit_data(sha) ⇒ Object
returns useful array of raw commit object data.
- #commit_tree(tree, opts = {}) ⇒ Object
- #config_get(name) ⇒ Object
- #config_list ⇒ Object
- #config_remote(name) ⇒ Object
-
#config_set(name, value) ⇒ Object
WRITE COMMANDS ##.
-
#conflicts ⇒ Object
:yields: file, your, their.
-
#current_command_version ⇒ Object
returns the current version of git, as an Array of Fixnums.
-
#describe(committish = nil, opts = {}) ⇒ Object
Returns most recent tag that is reachable from a commit.
-
#diff_files ⇒ Object
compares the index and the working directory.
- #diff_full(obj1 = 'HEAD', obj2 = nil, opts = {}) ⇒ Object
-
#diff_index(treeish) ⇒ Object
compares the index and the repository.
- #diff_name_status(reference1 = nil, reference2 = nil, opts = {}) ⇒ Object
- #diff_stats(obj1 = 'HEAD', obj2 = nil, opts = {}) ⇒ Object
- #fetch(remote, opts) ⇒ Object
- #full_log_commits(opts = {}) ⇒ Object
- #full_tree(sha) ⇒ Object
- #gc ⇒ Object
- #global_config_get(name) ⇒ Object
- #global_config_list ⇒ Object
- #global_config_set(name, value) ⇒ Object
-
#grep(string, opts = {}) ⇒ Object
returns hash [tree-ish] = [[line_no, match], [line_no, match2]] [tree-ish] = [[line_no, match], [line_no, match2]].
- #ignored_files ⇒ Object
-
#init(opts = {}) ⇒ Object
creates or reinitializes the repository.
-
#initialize(base = nil, logger = nil) ⇒ Lib
constructor
A new instance of Lib.
- #list_files(ref_dir) ⇒ Object
- #log_commits(opts = {}) ⇒ Object
- #ls_files(location = nil) ⇒ Object
- #ls_remote(location = nil) ⇒ Object
- #ls_tree(sha) ⇒ Object
- #meets_required_version? ⇒ Boolean
- #merge(branch, message = nil) ⇒ Object
- #merge_base(*args) ⇒ Object
- #mv(file1, file2) ⇒ Object
- #namerev(string) ⇒ Object
- #object_contents(sha, &block) ⇒ Object
- #object_size(sha) ⇒ Object
- #object_type(sha) ⇒ Object
- #parse_config(file) ⇒ Object
- #parse_config_list(lines) ⇒ Object
- #process_commit_data(data, sha = nil, indent = 4) ⇒ Object
- #process_commit_log_data(data) ⇒ Object
- #process_tag_data(data, name, indent = 4) ⇒ Object
- #pull(remote = 'origin', branch = 'master') ⇒ Object
- #push(remote, branch = 'master', opts = {}) ⇒ Object
-
#read_tree(treeish, opts = {}) ⇒ Object
reads a tree into the current index file.
- #remote_add(name, url, opts = {}) ⇒ Object
- #remote_remove(name) ⇒ Object
- #remote_set_url(name, url) ⇒ Object
- #remotes ⇒ Object
- #remove(path = '.', opts = {}) ⇒ Object
- #repack ⇒ Object
- #required_command_version ⇒ Object
- #reset(commit, opts = {}) ⇒ Object
- #revert(commitish, opts = {}) ⇒ Object
- #revparse(string) ⇒ Object
-
#show(objectish = nil, path = nil) ⇒ String
Shows objects.
- #stash_apply(id = nil) ⇒ Object
- #stash_clear ⇒ Object
- #stash_list ⇒ Object
- #stash_save(message) ⇒ Object
- #stashes_all ⇒ Object
- #tag(name, *opts) ⇒ Object
- #tag_data(name) ⇒ Object
- #tag_sha(tag_name) ⇒ Object
- #tags ⇒ Object
- #tree_depth(sha) ⇒ Object
- #unmerged ⇒ Object
- #update_ref(branch, commit) ⇒ Object
- #write_tree ⇒ Object
Constructor Details
#initialize(base = nil, logger = nil) ⇒ Lib
Returns a new instance of Lib.
13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 |
# File 'lib/git/lib.rb', line 13 def initialize(base = nil, logger = nil) @git_dir = nil @git_index_file = nil @git_work_dir = nil @path = nil if base.is_a?(Git::Base) @git_dir = base.repo.path @git_index_file = base.index.path if base.index @git_work_dir = base.dir.path if base.dir elsif base.is_a?(Hash) @git_dir = base[:repository] @git_index_file = base[:index] @git_work_dir = base[:working_directory] end @logger = logger end |
Instance Method Details
#add(paths = '.', options = {}) ⇒ Object
updates the repository index using the working directory content
lib.add('path/to/file')
lib.add(['path/to/file1','path/to/file2'])
lib.add(:all => true)
options:
:all => true
:force => true
524 525 526 527 528 529 530 531 532 533 534 535 536 537 |
# File 'lib/git/lib.rb', line 524 def add(paths='.',={}) arr_opts = [] arr_opts << '--all' if [:all] arr_opts << '--force' if [:force] arr_opts << '--' arr_opts << paths arr_opts.flatten! command('add', arr_opts) end |
#apply(patch_file) ⇒ Object
605 606 607 608 609 |
# File 'lib/git/lib.rb', line 605 def apply(patch_file) arr_opts = [] arr_opts << '--' << patch_file if patch_file command('apply', arr_opts) end |
#apply_mail(patch_file) ⇒ Object
611 612 613 614 615 |
# File 'lib/git/lib.rb', line 611 def apply_mail(patch_file) arr_opts = [] arr_opts << '--' << patch_file if patch_file command('am', arr_opts) end |
#archive(sha, file = nil, opts = {}) ⇒ Object
creates an archive file
options
:format (zip, tar)
:prefix
:remote
:path
867 868 869 870 871 872 873 874 875 876 877 878 879 880 881 882 883 884 885 886 887 888 889 890 891 |
# File 'lib/git/lib.rb', line 867 def archive(sha, file = nil, opts = {}) opts[:format] ||= 'zip' if opts[:format] == 'tgz' opts[:format] = 'tar' opts[:add_gzip] = true end if !file tempfile = Tempfile.new('archive') file = tempfile.path # delete it now, before we write to it, so that Ruby doesn't delete it # when it finalizes the Tempfile. tempfile.close! end arr_opts = [] arr_opts << "--format=#{opts[:format]}" if opts[:format] arr_opts << "--prefix=#{opts[:prefix]}" if opts[:prefix] arr_opts << "--remote=#{opts[:remote]}" if opts[:remote] arr_opts << sha arr_opts << '--' << opts[:path] if opts[:path] command('archive', arr_opts, true, (opts[:add_gzip] ? '| gzip' : '') + " > #{escape file}") return file end |
#branch_contains(commit, branch_name = "") ⇒ Object
322 323 324 |
# File 'lib/git/lib.rb', line 322 def branch_contains(commit, branch_name="") command("branch", [branch_name, "--contains", commit]) end |
#branch_current ⇒ Object
318 319 320 |
# File 'lib/git/lib.rb', line 318 def branch_current branches_all.select { |b| b[1] }.first[0] rescue nil end |
#branch_delete(branch) ⇒ Object
656 657 658 |
# File 'lib/git/lib.rb', line 656 def branch_delete(branch) command('branch', ['-D', branch]) end |
#branch_new(branch) ⇒ Object
652 653 654 |
# File 'lib/git/lib.rb', line 652 def branch_new(branch) command('branch', branch) end |
#branches_all ⇒ Object
302 303 304 305 306 307 308 309 |
# File 'lib/git/lib.rb', line 302 def branches_all arr = [] command_lines('branch', '-a').each do |b| current = (b[0, 2] == '* ') arr << [b.gsub('* ', '').strip, current] end arr end |
#change_head_branch(branch_name) ⇒ Object
298 299 300 |
# File 'lib/git/lib.rb', line 298 def change_head_branch(branch_name) command('symbolic-ref', ['HEAD', "refs/heads/#{branch_name}"]) end |
#checkout(branch, opts = {}) ⇒ Object
660 661 662 663 664 665 666 667 |
# File 'lib/git/lib.rb', line 660 def checkout(branch, opts = {}) arr_opts = [] arr_opts << '-b' if opts[:new_branch] || opts[:b] arr_opts << '--force' if opts[:force] || opts[:f] arr_opts << branch command('checkout', arr_opts) end |
#checkout_file(version, file) ⇒ Object
669 670 671 672 673 674 |
# File 'lib/git/lib.rb', line 669 def checkout_file(version, file) arr_opts = [] arr_opts << version arr_opts << file command('checkout', arr_opts) end |
#checkout_index(opts = {}) ⇒ Object
850 851 852 853 854 855 856 857 858 |
# File 'lib/git/lib.rb', line 850 def checkout_index(opts = {}) arr_opts = [] arr_opts << "--prefix=#{opts[:prefix]}" if opts[:prefix] arr_opts << "--force" if opts[:force] arr_opts << "--all" if opts[:all] arr_opts << '--' << opts[:path_limiter] if opts[:path_limiter].is_a? String command('checkout-index', arr_opts) end |
#clean(opts = {}) ⇒ Object
585 586 587 588 589 590 591 592 |
# File 'lib/git/lib.rb', line 585 def clean(opts = {}) arr_opts = [] arr_opts << '--force' if opts[:force] arr_opts << '-d' if opts[:d] arr_opts << '-x' if opts[:x] command('clean', arr_opts) end |
#clone(repository, name, opts = {}) ⇒ Object
tries to clone the given repo
returns :repository (if bare)
{:working_directory} otherwise
accepts options:
:bare:: no working directory
:branch:: name of branch to track (rather than 'master')
:depth:: the number of commits back to pull
:origin:: name of remote (same as remote)
:path:: directory where the repo will be cloned
:remote:: name of remote (rather than 'origin')
:recursive:: after the clone is created, initialize all submodules within, using their default settings.
TODO - make this work with SSH password or auth_key
60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 |
# File 'lib/git/lib.rb', line 60 def clone(repository, name, opts = {}) @path = opts[:path] || '.' clone_dir = opts[:path] ? File.join(@path, name) : name arr_opts = [] arr_opts << '--bare' if opts[:bare] arr_opts << '--branch' << opts[:branch] if opts[:branch] arr_opts << '--depth' << opts[:depth].to_i if opts[:depth] && opts[:depth].to_i > 0 arr_opts << '--config' << opts[:config] if opts[:config] arr_opts << '--origin' << opts[:remote] || opts[:origin] if opts[:remote] || opts[:origin] arr_opts << '--recursive' if opts[:recursive] arr_opts << "--mirror" if opts[:mirror] arr_opts << '--' arr_opts << repository arr_opts << clone_dir command('clone', arr_opts) (opts[:bare] or opts[:mirror]) ? {:repository => clone_dir} : {:working_directory => clone_dir} end |
#commit(message, opts = {}) ⇒ Object
Takes the commit message with the options and executes the commit command
accepts options:
:amend
:all
:allow_empty
:author
:date
:no_verify
565 566 567 568 569 570 571 572 573 574 575 576 |
# File 'lib/git/lib.rb', line 565 def commit(, opts = {}) arr_opts = [] arr_opts << "--message=#{message}" if arr_opts << '--amend' << '--no-edit' if opts[:amend] arr_opts << '--all' if opts[:add_all] || opts[:all] arr_opts << '--allow-empty' if opts[:allow_empty] arr_opts << "--author=#{opts[:author]}" if opts[:author] arr_opts << "--date=#{opts[:date]}" if opts[:date].is_a? String arr_opts << '--no-verify' if opts[:no_verify] command('commit', arr_opts) end |
#commit_data(sha) ⇒ Object
returns useful array of raw commit object data
176 177 178 179 180 |
# File 'lib/git/lib.rb', line 176 def commit_data(sha) sha = sha.to_s cdata = command_lines('cat-file', ['commit', sha]) process_commit_data(cdata, sha, 0) end |
#commit_tree(tree, opts = {}) ⇒ Object
833 834 835 836 837 838 839 840 841 842 843 844 |
# File 'lib/git/lib.rb', line 833 def commit_tree(tree, opts = {}) opts[:message] ||= "commit tree #{tree}" t = Tempfile.new('commit-message') t.write(opts[:message]) t.close arr_opts = [] arr_opts << tree arr_opts << '-p' << opts[:parent] if opts[:parent] arr_opts += [opts[:parents]].map { |p| ['-p', p] }.flatten if opts[:parents] command('commit-tree', arr_opts, true, "< #{escape t.path}") end |
#config_get(name) ⇒ Object
444 445 446 447 448 449 450 451 452 453 454 |
# File 'lib/git/lib.rb', line 444 def config_get(name) do_get = lambda do |path| command('config', ['--get', name]) end if @git_dir Dir.chdir(@git_dir, &do_get) else do_get.call end end |
#config_list ⇒ Object
460 461 462 463 464 465 466 467 468 469 470 |
# File 'lib/git/lib.rb', line 460 def config_list build_list = lambda do |path| parse_config_list command_lines('config', ['--list']) end if @git_dir Dir.chdir(@git_dir, &build_list) else build_list.call end end |
#config_remote(name) ⇒ Object
434 435 436 437 438 439 440 441 442 |
# File 'lib/git/lib.rb', line 434 def config_remote(name) hsh = {} config_list.each do |key, value| if /remote.#{name}/.match(key) hsh[key.gsub("remote.#{name}.", '')] = value end end hsh end |
#config_set(name, value) ⇒ Object
WRITE COMMANDS ##
504 505 506 |
# File 'lib/git/lib.rb', line 504 def config_set(name, value) command('config', [name, value]) end |
#conflicts ⇒ Object
:yields: file, your, their
706 707 708 709 710 711 712 713 714 715 |
# File 'lib/git/lib.rb', line 706 def conflicts # :yields: file, your, their self.unmerged.each do |f| your = Tempfile.new("YOUR-#{File.basename(f)}").path command('show', ":2:#{f}", true, "> #{escape your}") their = Tempfile.new("THEIR-#{File.basename(f)}").path command('show', ":3:#{f}", true, "> #{escape their}") yield(f, your, their) end end |
#current_command_version ⇒ Object
returns the current version of git, as an Array of Fixnums.
894 895 896 897 898 |
# File 'lib/git/lib.rb', line 894 def current_command_version output = command('version', [], false) version = output[/\d+\.\d+(\.\d+)+/] version.split('.').collect {|i| i.to_i} end |
#describe(committish = nil, opts = {}) ⇒ Object
Returns most recent tag that is reachable from a commit
accepts options:
:all
:tags
:contains
:debug
:exact_match
:dirty
:abbrev
:candidates
:long
:always
:math
@param [String|NilClass] committish target commit sha or object name
@param [{Symbol=>Object}] opts the given
@return [String] the tag name
106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 |
# File 'lib/git/lib.rb', line 106 def describe(committish=nil, opts={}) arr_opts = [] arr_opts << '--all' if opts[:all] arr_opts << '--tags' if opts[:tags] arr_opts << '--contains' if opts[:contains] arr_opts << '--debug' if opts[:debug] arr_opts << '--long' if opts[:long] arr_opts << '--always' if opts[:always] arr_opts << '--exact-match' if opts[:exact_match] || opts[:"exact-match"] arr_opts << '--dirty' if opts[:dirty] == true arr_opts << "--dirty=#{opts[:dirty]}" if opts[:dirty].is_a?(String) arr_opts << "--abbrev=#{opts[:abbrev]}" if opts[:abbrev] arr_opts << "--candidates=#{opts[:candidates]}" if opts[:candidates] arr_opts << "--match=#{opts[:match]}" if opts[:match] arr_opts << committish if committish return command('describe', arr_opts) end |
#diff_files ⇒ Object
compares the index and the working directory
394 395 396 |
# File 'lib/git/lib.rb', line 394 def diff_files diff_as_hash('diff-files') end |
#diff_full(obj1 = 'HEAD', obj2 = nil, opts = {}) ⇒ Object
350 351 352 353 354 355 356 357 |
# File 'lib/git/lib.rb', line 350 def diff_full(obj1 = 'HEAD', obj2 = nil, opts = {}) diff_opts = ['-p'] diff_opts << obj1 diff_opts << obj2 if obj2.is_a?(String) diff_opts << '--' << opts[:path_limiter] if opts[:path_limiter].is_a? String command('diff', diff_opts) end |
#diff_index(treeish) ⇒ Object
compares the index and the repository
399 400 401 |
# File 'lib/git/lib.rb', line 399 def diff_index(treeish) diff_as_hash('diff-index', treeish) end |
#diff_name_status(reference1 = nil, reference2 = nil, opts = {}) ⇒ Object
379 380 381 382 383 384 385 386 387 388 389 390 391 |
# File 'lib/git/lib.rb', line 379 def diff_name_status(reference1 = nil, reference2 = nil, opts = {}) opts_arr = ['--name-status'] opts_arr << reference1 if reference1 opts_arr << reference2 if reference2 opts_arr << '--' << opts[:path] if opts[:path] command_lines('diff', opts_arr).inject({}) do |memo, line| status, path = line.split("\t") memo[path] = status memo end end |
#diff_stats(obj1 = 'HEAD', obj2 = nil, opts = {}) ⇒ Object
359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 |
# File 'lib/git/lib.rb', line 359 def diff_stats(obj1 = 'HEAD', obj2 = nil, opts = {}) diff_opts = ['--numstat'] diff_opts << obj1 diff_opts << obj2 if obj2.is_a?(String) diff_opts << '--' << opts[:path_limiter] if opts[:path_limiter].is_a? String hsh = {:total => {:insertions => 0, :deletions => 0, :lines => 0, :files => 0}, :files => {}} command_lines('diff', diff_opts).each do |file| (insertions, deletions, filename) = file.split("\t") hsh[:total][:insertions] += insertions.to_i hsh[:total][:deletions] += deletions.to_i hsh[:total][:lines] = (hsh[:total][:deletions] + hsh[:total][:insertions]) hsh[:total][:files] += 1 hsh[:files][filename] = {:insertions => insertions.to_i, :deletions => deletions.to_i} end hsh end |
#fetch(remote, opts) ⇒ Object
774 775 776 777 778 779 780 781 782 |
# File 'lib/git/lib.rb', line 774 def fetch(remote, opts) arr_opts = [remote] arr_opts << opts[:ref] if opts[:ref] arr_opts << '--tags' if opts[:t] || opts[:tags] arr_opts << '--prune' if opts[:p] || opts[:prune] arr_opts << '--unshallow' if opts[:unshallow] command('fetch', arr_opts) end |
#full_log_commits(opts = {}) ⇒ Object
139 140 141 142 143 144 145 146 147 148 149 150 |
# File 'lib/git/lib.rb', line 139 def full_log_commits(opts={}) arr_opts = (opts) arr_opts << '--pretty=raw' arr_opts << "--skip=#{opts[:skip]}" if opts[:skip] arr_opts += (opts) full_log = command_lines('log', arr_opts, true) process_commit_log_data(full_log) end |
#full_tree(sha) ⇒ Object
290 291 292 |
# File 'lib/git/lib.rb', line 290 def full_tree(sha) command_lines('ls-tree', ['-r', sha]) end |
#gc ⇒ Object
817 818 819 |
# File 'lib/git/lib.rb', line 817 def gc command('gc', ['--prune', '--aggressive', '--auto']) end |
#global_config_get(name) ⇒ Object
456 457 458 |
# File 'lib/git/lib.rb', line 456 def global_config_get(name) command('config', ['--global', '--get', name], false) end |
#global_config_list ⇒ Object
472 473 474 |
# File 'lib/git/lib.rb', line 472 def global_config_list parse_config_list command_lines('config', ['--global', '--list'], false) end |
#global_config_set(name, value) ⇒ Object
508 509 510 |
# File 'lib/git/lib.rb', line 508 def global_config_set(name, value) command('config', ['--global', name, value], false) end |
#grep(string, opts = {}) ⇒ Object
returns hash
- tree-ish
-
[[line_no, match], [line_no, match2]]
- tree-ish
-
[[line_no, match], [line_no, match2]]
329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 |
# File 'lib/git/lib.rb', line 329 def grep(string, opts = {}) opts[:object] ||= 'HEAD' grep_opts = ['-n'] grep_opts << '-i' if opts[:ignore_case] grep_opts << '-v' if opts[:invert_match] grep_opts << '-e' grep_opts << string grep_opts << opts[:object] if opts[:object].is_a?(String) grep_opts << '--' << opts[:path_limiter] if opts[:path_limiter].is_a? String hsh = {} command_lines('grep', grep_opts).each do |line| if m = /(.*)\:(\d+)\:(.*)/.match(line) hsh[m[1]] ||= [] hsh[m[1]] << [m[2].to_i, m[3]] end end hsh end |
#ignored_files ⇒ Object
429 430 431 |
# File 'lib/git/lib.rb', line 429 def ignored_files command_lines('ls-files', ['--others', '-i', '--exclude-standard']) end |
#init(opts = {}) ⇒ Object
creates or reinitializes the repository
options:
:bare
:working_directory
37 38 39 40 41 42 |
# File 'lib/git/lib.rb', line 37 def init(opts={}) arr_opts = [] arr_opts << '--bare' if opts[:bare] command('init', arr_opts, false) end |
#list_files(ref_dir) ⇒ Object
311 312 313 314 315 316 |
# File 'lib/git/lib.rb', line 311 def list_files(ref_dir) dir = File.join(@git_dir, 'refs', ref_dir) files = [] Dir.chdir(dir) { files = Dir.glob('**/*').select { |f| File.file?(f) } } rescue nil files end |
#log_commits(opts = {}) ⇒ Object
129 130 131 132 133 134 135 136 137 |
# File 'lib/git/lib.rb', line 129 def log_commits(opts={}) arr_opts = (opts) arr_opts << '--pretty=oneline' arr_opts += (opts) command_lines('log', arr_opts, true).map { |l| l.split.first } end |
#ls_files(location = nil) ⇒ Object
403 404 405 406 407 408 409 410 411 412 413 |
# File 'lib/git/lib.rb', line 403 def ls_files(location=nil) location ||= '.' hsh = {} command_lines('ls-files', ['--stage', location]).each do |line| (info, file) = line.split("\t") (mode, sha, stage) = info.split file = eval(file) if file =~ /^\".*\"$/ # This takes care of quoted strings returned from git hsh[file] = {:path => file, :mode_index => mode, :sha_index => sha, :stage => stage} end hsh end |
#ls_remote(location = nil) ⇒ Object
415 416 417 418 419 420 421 422 423 424 425 426 427 |
# File 'lib/git/lib.rb', line 415 def ls_remote(location=nil) location ||= '.' Hash.new{ |h,k| h[k] = {} }.tap do |hsh| command_lines('ls-remote', [location], false).each do |line| (sha, info) = line.split("\t") (ref, type, name) = info.split('/', 3) type ||= 'head' type = 'branches' if type == 'heads' value = {:ref => ref, :sha => sha} hsh[type].update( name.nil? ? value : { name => value }) end end end |
#ls_tree(sha) ⇒ Object
274 275 276 277 278 279 280 281 282 283 284 |
# File 'lib/git/lib.rb', line 274 def ls_tree(sha) data = {'blob' => {}, 'tree' => {}} command_lines('ls-tree', sha).each do |line| (info, filenm) = line.split("\t") (mode, type, sha) = info.split data[type][filenm] = {:mode => mode, :sha => sha} end data end |
#meets_required_version? ⇒ Boolean
904 905 906 |
# File 'lib/git/lib.rb', line 904 def meets_required_version? (self.current_command_version <=> self.required_command_version) >= 0 end |
#merge(branch, message = nil) ⇒ Object
676 677 678 679 680 681 |
# File 'lib/git/lib.rb', line 676 def merge(branch, = nil) arr_opts = [] arr_opts << '-m' << if arr_opts += [branch] command('merge', arr_opts) end |
#merge_base(*args) ⇒ Object
683 684 685 686 687 688 689 690 691 692 693 694 695 696 |
# File 'lib/git/lib.rb', line 683 def merge_base(*args) opts = args.last.is_a?(Hash) ? args.pop : {} arg_opts = [] arg_opts << '--octopus' if opts[:octopus] arg_opts << '--independent' if opts[:independent] arg_opts << '--fork-point' if opts[:fork_point] arg_opts << '--all' if opts[:all] arg_opts += args command('merge-base', arg_opts).lines.map(&:strip) end |
#mv(file1, file2) ⇒ Object
286 287 288 |
# File 'lib/git/lib.rb', line 286 def mv(file1, file2) command_lines('mv', ['--', file1, file2]) end |
#namerev(string) ⇒ Object
163 164 165 |
# File 'lib/git/lib.rb', line 163 def namerev(string) command('name-rev', string).split[1] end |
#object_contents(sha, &block) ⇒ Object
270 271 272 |
# File 'lib/git/lib.rb', line 270 def object_contents(sha, &block) command('cat-file', ['-p', sha], &block) end |
#object_size(sha) ⇒ Object
171 172 173 |
# File 'lib/git/lib.rb', line 171 def object_size(sha) command('cat-file', ['-s', sha]).to_i end |
#object_type(sha) ⇒ Object
167 168 169 |
# File 'lib/git/lib.rb', line 167 def object_type(sha) command('cat-file', ['-t', sha]) end |
#parse_config(file) ⇒ Object
485 486 487 |
# File 'lib/git/lib.rb', line 485 def parse_config(file) parse_config_list command_lines('config', ['--list', '--file', file], false) end |
#parse_config_list(lines) ⇒ Object
476 477 478 479 480 481 482 483 |
# File 'lib/git/lib.rb', line 476 def parse_config_list(lines) hsh = {} lines.each do |line| (key, *values) = line.split('=') hsh[key] = values.join('=') end hsh end |
#process_commit_data(data, sha = nil, indent = 4) ⇒ Object
182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 |
# File 'lib/git/lib.rb', line 182 def process_commit_data(data, sha = nil, indent = 4) hsh = { 'sha' => sha, 'message' => '', 'parent' => [] } loop do key, *value = data.shift.split break if key.nil? if key == 'parent' hsh['parent'] << value.join(' ') else hsh[key] = value.join(' ') end end hsh['message'] = data.collect {|line| line[indent..-1]}.join("\n") + "\n" return hsh end |
#process_commit_log_data(data) ⇒ Object
231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 |
# File 'lib/git/lib.rb', line 231 def process_commit_log_data(data) = false hsh_array = [] hsh = nil data.each do |line| line = line.chomp if line[0].nil? = ! next end if hsh['message'] << "#{line[4..-1]}\n" next end key, *value = line.split value = value.join(' ') case key when 'commit' hsh_array << hsh if hsh hsh = {'sha' => value, 'message' => '', 'parent' => []} when 'parent' hsh['parent'] << value else hsh[key] = value end end hsh_array << hsh if hsh return hsh_array end |
#process_tag_data(data, name, indent = 4) ⇒ Object
212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 |
# File 'lib/git/lib.rb', line 212 def process_tag_data(data, name, indent=4) hsh = { 'name' => name, 'message' => '' } loop do key, *value = data.shift.split break if key.nil? hsh[key] = value.join(' ') end hsh['message'] = data.collect {|line| line[indent..-1]}.join("\n") + "\n" return hsh end |
#pull(remote = 'origin', branch = 'master') ⇒ Object
802 803 804 |
# File 'lib/git/lib.rb', line 802 def pull(remote='origin', branch='master') command('pull', [remote, branch]) end |
#push(remote, branch = 'master', opts = {}) ⇒ Object
784 785 786 787 788 789 790 791 792 793 794 795 796 797 798 799 800 |
# File 'lib/git/lib.rb', line 784 def push(remote, branch = 'master', opts = {}) # Small hack to keep backwards compatibility with the 'push(remote, branch, tags)' method signature. opts = {:tags => opts} if [true, false].include?(opts) arr_opts = [] arr_opts << '--mirror' if opts[:mirror] arr_opts << '--delete' if opts[:delete] arr_opts << '--force' if opts[:force] || opts[:f] arr_opts << remote if opts[:mirror] command('push', arr_opts) else command('push', arr_opts + [branch]) command('push', ['--tags'] + arr_opts) if opts[:tags] end end |
#read_tree(treeish, opts = {}) ⇒ Object
reads a tree into the current index file
822 823 824 825 826 827 |
# File 'lib/git/lib.rb', line 822 def read_tree(treeish, opts = {}) arr_opts = [] arr_opts << "--prefix=#{opts[:prefix]}" if opts[:prefix] arr_opts += [treeish] command('read-tree', arr_opts) end |
#remote_add(name, url, opts = {}) ⇒ Object
717 718 719 720 721 722 723 724 725 726 |
# File 'lib/git/lib.rb', line 717 def remote_add(name, url, opts = {}) arr_opts = ['add'] arr_opts << '-f' if opts[:with_fetch] || opts[:fetch] arr_opts << '-t' << opts[:track] if opts[:track] arr_opts << '--' arr_opts << name arr_opts << url command('remote', arr_opts) end |
#remote_remove(name) ⇒ Object
736 737 738 |
# File 'lib/git/lib.rb', line 736 def remote_remove(name) command('remote', ['rm', name]) end |
#remote_set_url(name, url) ⇒ Object
728 729 730 731 732 733 734 |
# File 'lib/git/lib.rb', line 728 def remote_set_url(name, url) arr_opts = ['set-url'] arr_opts << name arr_opts << url command('remote', arr_opts) end |
#remotes ⇒ Object
740 741 742 |
# File 'lib/git/lib.rb', line 740 def remotes command_lines('remote') end |
#remove(path = '.', opts = {}) ⇒ Object
539 540 541 542 543 544 545 546 547 548 549 550 551 |
# File 'lib/git/lib.rb', line 539 def remove(path = '.', opts = {}) arr_opts = ['-f'] # overrides the up-to-date check by default arr_opts << ['-r'] if opts[:recursive] arr_opts << ['--cached'] if opts[:cached] arr_opts << '--' if path.is_a?(Array) arr_opts += path else arr_opts << path end command('rm', arr_opts) end |
#repack ⇒ Object
813 814 815 |
# File 'lib/git/lib.rb', line 813 def repack command('repack', ['-a', '-d']) end |
#required_command_version ⇒ Object
900 901 902 |
# File 'lib/git/lib.rb', line 900 def required_command_version [1, 6] end |
#reset(commit, opts = {}) ⇒ Object
578 579 580 581 582 583 |
# File 'lib/git/lib.rb', line 578 def reset(commit, opts = {}) arr_opts = [] arr_opts << '--hard' if opts[:hard] arr_opts << commit if commit command('reset', arr_opts) end |
#revert(commitish, opts = {}) ⇒ Object
594 595 596 597 598 599 600 601 602 603 |
# File 'lib/git/lib.rb', line 594 def revert(commitish, opts = {}) # Forcing --no-edit as default since it's not an interactive session. opts = {:no_edit => true}.merge(opts) arr_opts = [] arr_opts << '--no-edit' if opts[:no_edit] arr_opts << commitish command('revert', arr_opts) end |
#revparse(string) ⇒ Object
152 153 154 155 156 157 158 159 160 161 |
# File 'lib/git/lib.rb', line 152 def revparse(string) return string if string =~ /^[A-Fa-f0-9]{40}$/ # passing in a sha - just no-op it rev = ['head', 'remotes', 'tags'].map do |d| File.join(@git_dir, 'refs', d, string) end.find do |path| File.file?(path) end return File.read(rev).chomp if rev command('rev-parse', string) end |
#show(objectish = nil, path = nil) ⇒ String
Shows objects
494 495 496 497 498 499 500 |
# File 'lib/git/lib.rb', line 494 def show(objectish=nil, path=nil) arr_opts = [] arr_opts << (path ? "#{objectish}:#{path}" : objectish) command('show', arr_opts.compact) end |
#stash_apply(id = nil) ⇒ Object
636 637 638 639 640 641 642 |
# File 'lib/git/lib.rb', line 636 def stash_apply(id = nil) if id command('stash apply', [id]) else command('stash apply') end end |
#stash_clear ⇒ Object
644 645 646 |
# File 'lib/git/lib.rb', line 644 def stash_clear command('stash clear') end |
#stash_list ⇒ Object
648 649 650 |
# File 'lib/git/lib.rb', line 648 def stash_list command('stash list') end |
#stash_save(message) ⇒ Object
631 632 633 634 |
# File 'lib/git/lib.rb', line 631 def stash_save() output = command('stash save', []) output =~ /HEAD is now at/ end |
#stashes_all ⇒ Object
617 618 619 620 621 622 623 624 625 626 627 628 629 |
# File 'lib/git/lib.rb', line 617 def stashes_all arr = [] filename = File.join(@git_dir, 'logs/refs/stash') if File.exist?(filename) File.open(filename) do |f| f.each_with_index do |line, i| m = line.match(/:(.*)$/) arr << [i, m[1].strip] end end end arr end |
#tag(name, *opts) ⇒ Object
748 749 750 751 752 753 754 755 756 757 758 759 760 761 762 763 764 765 766 767 768 769 770 771 |
# File 'lib/git/lib.rb', line 748 def tag(name, *opts) target = opts[0].instance_of?(String) ? opts[0] : nil opts = opts.last.instance_of?(Hash) ? opts.last : {} if (opts[:a] || opts[:annotate]) && !(opts[:m] || opts[:message]) raise "Can not create an [:a|:annotate] tag without the precense of [:m|:message]." end arr_opts = [] arr_opts << '-f' if opts[:force] || opts[:f] arr_opts << '-a' if opts[:a] || opts[:annotate] arr_opts << '-s' if opts[:s] || opts[:sign] arr_opts << '-d' if opts[:d] || opts[:delete] arr_opts << name arr_opts << target if target if opts[:m] || opts[:message] arr_opts << '-m' << (opts[:m] || opts[:message]) end command('tag', arr_opts) end |
#tag_data(name) ⇒ Object
206 207 208 209 210 |
# File 'lib/git/lib.rb', line 206 def tag_data(name) sha = sha.to_s tdata = command_lines('cat-file', ['tag', name]) process_tag_data(tdata, name, 0) end |
#tag_sha(tag_name) ⇒ Object
806 807 808 809 810 811 |
# File 'lib/git/lib.rb', line 806 def tag_sha(tag_name) head = File.join(@git_dir, 'refs', 'tags', tag_name) return File.read(head).chomp if File.exist?(head) command('show-ref', ['--tags', '-s', tag_name]) end |
#tags ⇒ Object
744 745 746 |
# File 'lib/git/lib.rb', line 744 def command_lines('tag') end |
#tree_depth(sha) ⇒ Object
294 295 296 |
# File 'lib/git/lib.rb', line 294 def tree_depth(sha) full_tree(sha).size end |
#unmerged ⇒ Object
698 699 700 701 702 703 704 |
# File 'lib/git/lib.rb', line 698 def unmerged unmerged = [] command_lines('diff', ["--cached"]).each do |line| unmerged << $1 if line =~ /^\* Unmerged path (.*)/ end unmerged end |
#update_ref(branch, commit) ⇒ Object
846 847 848 |
# File 'lib/git/lib.rb', line 846 def update_ref(branch, commit) command('update-ref', [branch, commit]) end |
#write_tree ⇒ Object
829 830 831 |
# File 'lib/git/lib.rb', line 829 def write_tree command('write-tree') end |