Module: Git::Repository::Logging Private
- Included in:
- Git::Repository
- Defined in:
- lib/git/repository/logging.rb
Overview
This module is part of a private API. You should avoid using this module if possible, as it may be removed or be changed in the future.
Facade methods for querying commit history
Included by Git::Repository.
Instance Method Summary collapse
-
#full_log_commits(opts = {}) ⇒ Array<Hash>
private
Returns commits within the given revision range.
-
#log(count = 30) ⇒ Git::Log
private
Returns a new Log query builder scoped to this repository.
Instance Method Details
#full_log_commits(opts = {}) ⇒ Array<Hash>
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Returns commits within the given revision range
81 82 83 84 85 86 87 88 89 |
# File 'lib/git/repository/logging.rb', line 81 def full_log_commits(opts = {}) SharedPrivate.assert_valid_opts!(FULL_LOG_COMMITS_ALLOWED_OPTS, **opts) Private.validate_log_count_option!(opts) Private.validate_log_between_option!(opts) call_opts = Private.(opts, skip: opts[:skip], merges: opts[:merges]) revision_range_args = Private.log_revision_range_args(opts) Private.run_log_command(@execution_context, revision_range_args, call_opts) end |
#log(count = 30) ⇒ Git::Log
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Returns a new Log query builder scoped to this repository
104 105 106 |
# File 'lib/git/repository/logging.rb', line 104 def log(count = 30) Git::Log.new(self, count) end |