Class: Git::StashInfo
- Inherits:
-
Data
- Object
- Data
- Git::StashInfo
- Defined in:
- lib/git/stash_info.rb
Overview
Immutable value object representing stash entry information
StashInfo encapsulates the parsed data from git stash list output.
Each entry contains comprehensive information about the stash including
its index, reference name, commit SHA, branch, message, author/committer
details, and timestamps.
Instance Attribute Summary collapse
-
#author_date ⇒ Object
readonly
Returns the value of attribute author_date.
-
#author_email ⇒ Object
readonly
Returns the value of attribute author_email.
-
#author_name ⇒ Object
readonly
Returns the value of attribute author_name.
-
#branch ⇒ Object
readonly
Returns the value of attribute branch.
-
#committer_date ⇒ Object
readonly
Returns the value of attribute committer_date.
-
#committer_email ⇒ Object
readonly
Returns the value of attribute committer_email.
-
#committer_name ⇒ Object
readonly
Returns the value of attribute committer_name.
-
#index ⇒ Object
readonly
Returns the value of attribute index.
-
#message ⇒ Object
readonly
Returns the value of attribute message.
-
#name ⇒ Object
readonly
Returns the value of attribute name.
-
#oid ⇒ Object
readonly
Returns the value of attribute oid.
-
#short_oid ⇒ Object
readonly
Returns the value of attribute short_oid.
Instance Method Summary collapse
-
#to_s ⇒ String
Returns the stash reference name.
Instance Attribute Details
#author_date ⇒ Object (readonly)
Returns the value of attribute author_date
79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 |
# File 'lib/git/stash_info.rb', line 79 StashInfo = Data.define( :index, :name, :oid, :short_oid, :branch, :message, :author_name, :author_email, :author_date, :committer_name, :committer_email, :committer_date ) do # Returns the stash reference name # # @return [String] the stash name (e.g., 'stash@\\{0}') # # @example # info.to_s # => 'stash@{0}' # def to_s name end end |
#author_email ⇒ Object (readonly)
Returns the value of attribute author_email
79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 |
# File 'lib/git/stash_info.rb', line 79 StashInfo = Data.define( :index, :name, :oid, :short_oid, :branch, :message, :author_name, :author_email, :author_date, :committer_name, :committer_email, :committer_date ) do # Returns the stash reference name # # @return [String] the stash name (e.g., 'stash@\\{0}') # # @example # info.to_s # => 'stash@{0}' # def to_s name end end |
#author_name ⇒ Object (readonly)
Returns the value of attribute author_name
79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 |
# File 'lib/git/stash_info.rb', line 79 StashInfo = Data.define( :index, :name, :oid, :short_oid, :branch, :message, :author_name, :author_email, :author_date, :committer_name, :committer_email, :committer_date ) do # Returns the stash reference name # # @return [String] the stash name (e.g., 'stash@\\{0}') # # @example # info.to_s # => 'stash@{0}' # def to_s name end end |
#branch ⇒ Object (readonly)
Returns the value of attribute branch
79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 |
# File 'lib/git/stash_info.rb', line 79 StashInfo = Data.define( :index, :name, :oid, :short_oid, :branch, :message, :author_name, :author_email, :author_date, :committer_name, :committer_email, :committer_date ) do # Returns the stash reference name # # @return [String] the stash name (e.g., 'stash@\\{0}') # # @example # info.to_s # => 'stash@{0}' # def to_s name end end |
#committer_date ⇒ Object (readonly)
Returns the value of attribute committer_date
79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 |
# File 'lib/git/stash_info.rb', line 79 StashInfo = Data.define( :index, :name, :oid, :short_oid, :branch, :message, :author_name, :author_email, :author_date, :committer_name, :committer_email, :committer_date ) do # Returns the stash reference name # # @return [String] the stash name (e.g., 'stash@\\{0}') # # @example # info.to_s # => 'stash@{0}' # def to_s name end end |
#committer_email ⇒ Object (readonly)
Returns the value of attribute committer_email
79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 |
# File 'lib/git/stash_info.rb', line 79 StashInfo = Data.define( :index, :name, :oid, :short_oid, :branch, :message, :author_name, :author_email, :author_date, :committer_name, :committer_email, :committer_date ) do # Returns the stash reference name # # @return [String] the stash name (e.g., 'stash@\\{0}') # # @example # info.to_s # => 'stash@{0}' # def to_s name end end |
#committer_name ⇒ Object (readonly)
Returns the value of attribute committer_name
79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 |
# File 'lib/git/stash_info.rb', line 79 StashInfo = Data.define( :index, :name, :oid, :short_oid, :branch, :message, :author_name, :author_email, :author_date, :committer_name, :committer_email, :committer_date ) do # Returns the stash reference name # # @return [String] the stash name (e.g., 'stash@\\{0}') # # @example # info.to_s # => 'stash@{0}' # def to_s name end end |
#index ⇒ Object (readonly)
Returns the value of attribute index
79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 |
# File 'lib/git/stash_info.rb', line 79 StashInfo = Data.define( :index, :name, :oid, :short_oid, :branch, :message, :author_name, :author_email, :author_date, :committer_name, :committer_email, :committer_date ) do # Returns the stash reference name # # @return [String] the stash name (e.g., 'stash@\\{0}') # # @example # info.to_s # => 'stash@{0}' # def to_s name end end |
#message ⇒ Object (readonly)
Returns the value of attribute message
79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 |
# File 'lib/git/stash_info.rb', line 79 StashInfo = Data.define( :index, :name, :oid, :short_oid, :branch, :message, :author_name, :author_email, :author_date, :committer_name, :committer_email, :committer_date ) do # Returns the stash reference name # # @return [String] the stash name (e.g., 'stash@\\{0}') # # @example # info.to_s # => 'stash@{0}' # def to_s name end end |
#name ⇒ Object (readonly)
Returns the value of attribute name
79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 |
# File 'lib/git/stash_info.rb', line 79 StashInfo = Data.define( :index, :name, :oid, :short_oid, :branch, :message, :author_name, :author_email, :author_date, :committer_name, :committer_email, :committer_date ) do # Returns the stash reference name # # @return [String] the stash name (e.g., 'stash@\\{0}') # # @example # info.to_s # => 'stash@{0}' # def to_s name end end |
#oid ⇒ Object (readonly)
Returns the value of attribute oid
79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 |
# File 'lib/git/stash_info.rb', line 79 StashInfo = Data.define( :index, :name, :oid, :short_oid, :branch, :message, :author_name, :author_email, :author_date, :committer_name, :committer_email, :committer_date ) do # Returns the stash reference name # # @return [String] the stash name (e.g., 'stash@\\{0}') # # @example # info.to_s # => 'stash@{0}' # def to_s name end end |
#short_oid ⇒ Object (readonly)
Returns the value of attribute short_oid
79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 |
# File 'lib/git/stash_info.rb', line 79 StashInfo = Data.define( :index, :name, :oid, :short_oid, :branch, :message, :author_name, :author_email, :author_date, :committer_name, :committer_email, :committer_date ) do # Returns the stash reference name # # @return [String] the stash name (e.g., 'stash@\\{0}') # # @example # info.to_s # => 'stash@{0}' # def to_s name end end |
Instance Method Details
#to_s ⇒ String
Returns the stash reference name
100 101 102 |
# File 'lib/git/stash_info.rb', line 100 def to_s name end |