Class: Git::TagDeleteFailure

Inherits:
Data
  • Object
show all
Defined in:
lib/git/tag_delete_failure.rb

Overview

Represents a tag that failed to be deleted

This is an immutable data object returned as part of TagDeleteResult when one or more tags could not be deleted.

Examples:

failure = Git::TagDeleteFailure.new(
  name: 'nonexistent',
  error_message: "tag 'nonexistent' not found."
)
failure.name          #=> 'nonexistent'
failure.error_message #=> "tag 'nonexistent' not found."

See Also:

Instance Attribute Summary collapse

Instance Attribute Details

#error_messageObject (readonly)

Returns the value of attribute error_message

Returns:

  • (Object)

    the current value of error_message



30
# File 'lib/git/tag_delete_failure.rb', line 30

TagDeleteFailure = Data.define(:name, :error_message)

#nameObject (readonly)

Returns the value of attribute name

Returns:

  • (Object)

    the current value of name



30
# File 'lib/git/tag_delete_failure.rb', line 30

TagDeleteFailure = Data.define(:name, :error_message)